# Welcome to flaskmng
[![Documentation Status](https://readthedocs.org/projects/flaskmng/badge/?version=latest)](https://flaskmng.readthedocs.io/en/latest/?badge=latest)
## What is flaskmng?

**flaskmng** is a tool that manages Flask project. It is designed in MVT architecture.

## Documentation
Documentation **flaskmng** is [flaskmng.readthedocs.io](https://flaskmng.readthedocs.io)